aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org/apache/fop/fo/pagination/SubSequenceSpecifier.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/java/org/apache/fop/fo/pagination/SubSequenceSpecifier.java')
-rw-r--r--src/java/org/apache/fop/fo/pagination/SubSequenceSpecifier.java5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/java/org/apache/fop/fo/pagination/SubSequenceSpecifier.java b/src/java/org/apache/fop/fo/pagination/SubSequenceSpecifier.java
index 5da4945f1..0bad65a7c 100644
--- a/src/java/org/apache/fop/fo/pagination/SubSequenceSpecifier.java
+++ b/src/java/org/apache/fop/fo/pagination/SubSequenceSpecifier.java
@@ -19,7 +19,6 @@
package org.apache.fop.fo.pagination;
-import org.apache.fop.apps.FOPException;
/**
* Classes that implement this interface can be added to a PageSequenceMaster,
@@ -35,14 +34,14 @@ public interface SubSequenceSpecifier {
* @param isOnlyPage True if the next page is the only page
* @param isBlankPage True if the next page is blank
* @return the page master name
* @throws FOPException if there's a problem determining the next page master
*/
String getNextPageMasterName(boolean isOddPage,
boolean isFirstPage,
boolean isLastPage,
boolean isOnlyPage,
boolean isBlankPage)
- throws FOPException;
+ throws PageProductionException;
/**
* Called before a new page sequence is rendered so subsequences can reset
@@ -35,14 +34,14 @@ public interface SubSequenceSpecifier {
* @param isBlankPage True if the next page is blank
* @return the page master name
- * @throws FOPException if there's a problem determining the next page master
+ * @throws PageProductionException if there's a problem determining the next page master
*/
String getNextPageMasterName(boolean isOddPage,